@@ -3,14 +3,11 @@ import six
 import time
 import pandas as pd
 import numpy as np
-from pathlib import Path
-from warnings import warn
 from symengine import Add, sympify
 from dexom_python.enum_functions.icut_functions import create_icut_constraint
 from dexom_python.imat_functions import imat
-from dexom_python.result_functions import read_solution
 from dexom_python.model_functions import load_reaction_weights, read_model, check_model_options, DEFAULT_VALUES
-from dexom_python.enum_functions.enumeration import EnumSolution, get_recent_solution_and_iteration, create_enum_variables
+from dexom_python.enum_functions.enumeration import EnumSolution, create_enum_variables, read_prev_sol
 
 
 def create_maxdist_constraint(model, reaction_weights, prev_sol, obj_tol, name='maxdist_optimality', full=False):
@@ -190,32 +187,14 @@ def main():
     reaction_weights = {}
     if args.reaction_weights is not None:
         reaction_weights = load_reaction_weights(args.reaction_weights)
-
-    prev_sol_success = False
-    if args.prev_sol is not None:
-        prev_sol_path = Path(args.prev_sol)
-        if prev_sol_path.is_file():
-            prev_sol, prev_bin = read_solution(args.prev_sol, model)
-            model = create_enum_variables(model, reaction_weights, eps=args.epsilon, thr=args.threshold, full=args.full)
-            prev_sol_success = True
-        elif prev_sol_path.is_dir():
-            try:
-                prev_sol, i = get_recent_solution_and_iteration(args.prev_sol, args.startsol_num)
-            except:
-                warn('Could not find solution in directory %s, computing new starting solution' % args.prev_sol)
-            else:
-                model = create_enum_variables(model, reaction_weights, eps=args.epsilon, thr=args.threshold,
-                                              full=args.full)
-                prev_sol_success = True
-        else:
-            warn('Could not read previous solution at path %s, computing new starting solution' % args.prev_sol)
-    if not prev_sol_success:
-        prev_sol = imat(model, reaction_weights, epsilon=args.epsilon, threshold=args.threshold)
+    prev_sol, _ = read_prev_sol(prev_sol_arg=args.prev_sol, model=model, rw=reaction_weights, eps=args.epsilon,
+                                thr=args.threshold, full=args.full)
     icut = False if args.noicut else True
     maxdist_sol = maxdist(model=model, reaction_weights=reaction_weights, prev_sol=prev_sol, eps=args.epsilon,
                           thr=args.threshold, obj_tol=args.obj_tol, maxiter=args.maxiter, icut=icut, full=args.full,
                           only_ones=args.onlyones)
     sol = pd.DataFrame(maxdist_sol.binary)
+    sol.columns = [r.id for r in model.reactions]
     sol.to_csv(args.output+'_solutions.csv')
     return True
 
